@@ -21,7 +21,7 @@ char rbuf[2048];
     printf("%s = %s\n", label,rbuf); }
 #endif
 
-unsigned char ver[]="@(#)L3 1.1b - Mark C. Henderson - markh@wimsey.bc.ca";
+unsigned char ver[]="@(#)L3 1.2 - Mark C. Henderson - markh@wimsey.bc.ca";
 
 #ifndef STAND
 extern void ferr(char *);
@@ -172,6 +172,46 @@ static unsigned int tiny_primes[] = {
         191,193,197,199,211,223,227,229,233,239,241,251 };
 #define ntiny_primes 53
 
+int probab_prime(MP_INT *p)
+{
+	MP_INT *t; int i;
+	int status;
+
+    /* is p even */
+    if (!(mpz_get_ui(p) % 2)) 
+        return 0;
+    init(t);
+    for (i=0; i<ntiny_primes; i++) {
+
+        /* t = p % tiny_primes[i] */
+        mpz_mmod_ui(t,p,tiny_primes[i]);
+
+        /* if t = 0,  p sure isn't prime */
+        if (!mpz_cmp_ui(t,0)) {
+            clear(t); return 0;
+        }
+    }
+    /* t = 2 ^ p mod p */
+    mpz_set_ui(t,2); mpz_powm(t,t,p,p);
+
+    /* if (t != 2) */
+    if (mpz_cmp_ui(t,2)) {
+        clear(t); return 0;
+    }
+
+    /* t = 3 ^ p mod p */
+    mpz_set_ui(t,3); mpz_powm(t,t,p,p);
+
+    /* if (t != 3) */
+    if (mpz_cmp_ui(t,3)) {
+        clear(t); return 0;
+    }
+
+	/* really don't need to do this unless lightening strikes */
+    status = mpz_probab_prime_p(p,5);
+									
+}
+
 int
 good_prime(MP_INT *p, MP_INT *e)
 {
@@ -179,8 +219,7 @@ good_prime(MP_INT *p, MP_INT *e)
     int status;
 
     /* is p even */
-    i = mpz_get_ui(p);
-    if (!(i % 2)) 
+    if (!(mpz_get_ui(p) % 2)) 
         return 0;
         
     init(t);
@@ -201,6 +240,14 @@ good_prime(MP_INT *p, MP_INT *e)
     if (mpz_cmp_ui(t,2)) {
         clear(t); return 0;
     }
+
+    /* t = 3 ^ p mod p */
+    mpz_set_ui(t,3); mpz_powm(t,t,p,p);
+
+    /* if (t != 3) */
+    if (mpz_cmp_ui(t,3)) {
+        clear(t); return 0;
+    }
     
     init(g);
 
@@ -228,8 +275,9 @@ good_prime(MP_INT *p, MP_INT *e)
         clear(t); clear(g); return 0;
     }
 
-    status = mpz_probab_prime_p(p,20);
-
+	/* really don't need to do this unless lightening strikes */
+    status = mpz_probab_prime_p(p,5);
+									
     clear(t); clear(g); return status;
 }
 
@@ -237,7 +285,7 @@ good_prime(MP_INT *p, MP_INT *e)
 
 /* genkey generates a LUCAS private key
     p,q are "returned"
-    e is input public key
+    e is input public key which may be altered
     bits is requested number of bits for each of p and q
     randbuf is an array of user supplied "random" data
     randbuflen is the length of randbuf
@@ -258,8 +306,8 @@ genkey(MP_INT *p, MP_INT *q,  MP_INT *e, unsigned int bits) {
 #if 0
     MP_INT *tp; MP_INT *tq; 
 #endif 
-	MP_INT *t;
-	int i;
+    MP_INT *t;
+    int i;
     int bytes = (bits + 7)/8;
     unsigned char *randbuf;
 
@@ -272,22 +320,22 @@ genkey(MP_INT *p, MP_INT *q,  MP_INT *e, unsigned int bits) {
     cstmp(q, randbuf + bytes + SHIFT, bytes-SHIFT);
 
 #ifdef DEBUG
-	fprintf(stderr, "debug genkey: pi = %s\n", mpz_get_str(NULL,16,p));
-	fprintf(stderr, "debug genkey: qi = %s\n", mpz_get_str(NULL,16,q));
+    fprintf(stderr, "debug genkey: pi = %s\n", mpz_get_str(NULL,16,p));
+    fprintf(stderr, "debug genkey: qi = %s\n", mpz_get_str(NULL,16,q));
 #endif
 
     for (i=0;i<bytes+bytes;i++)
         *(randbuf+i) = 0;
     free(randbuf);
 
-	init(t);
+    init(t);
 #if 0
     init(tp); init(tq);
     mpz_set_ui(t,1);
     mpz_mul_2exp(t,t,bits);
     mpz_div_2exp(t,t,1);
-	mpz_mul_2exp(tp,t,SHIFT*8);
-	mpz_div_2exp(tq,t,SHIFT*8);
+    mpz_mul_2exp(tp,t,SHIFT*8);
+    mpz_div_2exp(tq,t,SHIFT*8);
     if (mpz_cmp(p,tp) < 0)
         mpz_add(p,tp,p);
     if (mpz_cmp(q,tq) < 0)
@@ -299,6 +347,19 @@ genkey(MP_INT *p, MP_INT *q,  MP_INT *e, unsigned int bits) {
     if (even(q))
         mpz_add_ui(q,q,1);
 
+#ifndef FIXED_E
+	/* make sure that e is odd */
+	if (even(e))
+        mpz_add_ui(e,e,1);
+
+	/* I'm partial to prime e - although there is no reason we really
+     *  need to make e prime 
+     */
+    while (!probab_prime(e))
+        mpz_add_ui(e,e,2);
+
+#endif
+
     while (!good_prime(p,e))
         mpz_add_ui(p,p,2);
     while (!good_prime(q,e))
@@ -308,7 +369,7 @@ genkey(MP_INT *p, MP_INT *q,  MP_INT *e, unsigned int bits) {
     if (mpz_cmp(p,q) < 0) {
         mpz_set(t,p); mpz_set(p,q); mpz_set(q,t);
     }
-	clear(t);
+    clear(t);
 
 #if 0
     clear(tp); clear(tq);
@@ -958,13 +1019,13 @@ int vsign(MP_INT *c, unsigned char *hash, MP_INT *n, MP_INT *e, int alg)
             return 0;
     for (i=1;i < nn-HASHLEN;i++)
         if (ribuf[i] != 0xff) {
-			clear(m);
+            clear(m);
             return 0;
-		}
+        }
     if (ribuf[0] != 0) {
-		clear(m);
+        clear(m);
         return 0;
-	}
+    }
     clear(m);
     return 1;
 }
