@@ -14,7 +14,7 @@ unsigned char iv[8];
 unsigned char eiv[8];
 extern unsigned char ver[];
 
-#if defined(sun) || defined(_AIX) || defined(svr4) || defined(hpux)
+#if defined(sun) || defined(_AIX) || defined(svr4) || defined(hpux) || defined(linux)
 #define USE_FSYNC
 #endif
 
@@ -63,7 +63,7 @@ unsigned long int textsize = 0, codesize = 0, printcount = 0;
 int             do_decomp = 0;
 int             exit_stat = 0;  /* per-file status */
 int             perm_stat = 0;  /* permanent status */
-int 			debug = 0;
+int             debug = 0;
 #ifndef DEBUG
 int             test_mode = 0;  /* for testing purposes */
 #else
@@ -136,12 +136,12 @@ main(argc, argv)
                     break;
 
                 case 't':
-		    test_mode=1;
-		    break;
-			case 'D':
-				debug=1;
-				break;
-			case 'w':
+            test_mode=1;
+            break;
+            case 'D':
+                debug=1;
+                break;
+            case 'w':
                     wipe_old_file = 0;
                     break;
                 case 'W': /* triple wipe */
@@ -292,7 +292,7 @@ nextarg:    continue;
         }
     }
     zap(eiv,8); zap(key,48); zap(iv,8); 
-	closerandom();
+    closerandom();
     exit(perm_stat ? perm_stat : exit_stat);
 }
 
@@ -307,56 +307,56 @@ int decrypt;
     }
     if (!havekey)  {
         unsigned char *ss = NULL,*tt = NULL;
-	do {
-		if (ss) {zap(ss,strlen(ss)); free(ss); } 
-		if (tt) {zap(tt,strlen(tt)); free(tt); }
-		fprintf(stderr, "enter password: ");
-		ss = getstring(1);
-		fprintf(stderr, "enter password again: ");
-        	tt = getstring(1);
-	} while (strcmp(ss,tt));
-	zap(tt,strlen(tt));
-	mdstring(ss,strlen(ss),key);
-	sn512string(ss,strlen(ss), &key[16]);
-	if (debug) {
-		fprintf(stderr, "\npto key:\n   ");
-		for (i=0;i<24;i++)
-			fprintf(stderr, "%02x", key[i]);
-		fprintf(stderr, "\n   ");
-		for (i=24;i<48;i++)
-			fprintf(stderr, "%02x", key[i]);
-		fprintf(stderr, "\n");
-	}
+    do {
+        if (ss) {zap(ss,strlen(ss)); free(ss); } 
+        if (tt) {zap(tt,strlen(tt)); free(tt); }
+        fprintf(stderr, "enter password: ");
+        ss = getstring(1);
+        fprintf(stderr, "enter password again: ");
+            tt = getstring(1);
+    } while (strcmp(ss,tt));
+    zap(tt,strlen(tt));
+    mdstring(ss,strlen(ss),key);
+    sn512string(ss,strlen(ss), &key[16]);
+    if (debug) {
+        fprintf(stderr, "\npto key:\n   ");
+        for (i=0;i<24;i++)
+            fprintf(stderr, "%02x", key[i]);
+        fprintf(stderr, "\n   ");
+        for (i=24;i<48;i++)
+            fprintf(stderr, "%02x", key[i]);
+        fprintf(stderr, "\n");
+    }
 
-	if (debug) {
-		fprintf(stderr, "\nraw key:\n   ");
-		for (i=0;i<24;i++)
-			fprintf(stderr, "%02x", key[i]);
-		fprintf(stderr, "\n   ");
-		for (i=24;i<48;i++)
-			fprintf(stderr, "%02x", key[i]);
-		fprintf(stderr, "\n");
-	}
+    if (debug) {
+        fprintf(stderr, "\nraw key:\n   ");
+        for (i=0;i<24;i++)
+            fprintf(stderr, "%02x", key[i]);
+        fprintf(stderr, "\n   ");
+        for (i=24;i<48;i++)
+            fprintf(stderr, "%02x", key[i]);
+        fprintf(stderr, "\n");
+    }
         zap(ss,strlen(tt));
     }
     havekey=1;
     if (!decrypt) {
-	for (i=0;i<8;i++)
-		iv[i] = randombyte();
-	fwrite(iv,1,8,stdout);
+    for (i=0;i<8;i++)
+        iv[i] = randombyte();
+    fwrite(iv,1,8,stdout);
     }
     else {
-		i=fread(iv,1,8,stdin);
-		if (i < 8) {
-			fprintf(stderr, "short file\n");
-			oops();
-		}
-    }	
+        i=fread(iv,1,8,stdin);
+        if (i < 8) {
+            fprintf(stderr, "short file\n");
+            oops();
+        }
+    }   
     if (debug) {
-		fprintf(stderr, "iv : ");
-		for (i=0;i<8;i++)
-			fprintf(stderr, "%02x", iv[i]);
-		fprintf(stderr, "\n");
+        fprintf(stderr, "iv : ");
+        for (i=0;i<8;i++)
+            fprintf(stderr, "%02x", iv[i]);
+        fprintf(stderr, "\n");
     }
     ret = desfile(stdin, stdout, key, iv, decrypt);
     if (!ret) {
@@ -411,7 +411,7 @@ int val;
         fprintf(stderr, "fsync failed!\n");
 #endif
     fclose(fle);
-#ifdef linux
+#ifdef oldlinux
 /*best we can do-although linux has O_SYNC defined it isn't implemented yet*/
     sync();
 #endif
@@ -514,7 +514,7 @@ onintr()
         fprintf(stderr, "\nSIGINT -- exiting\n");
     if (!precious)
         unlink(ofname);
-	closerandom();
+    closerandom();
     exit(1);
 }
 
@@ -524,9 +524,9 @@ oops()
     if (do_decomp)
         fprintf(stderr, "corrupt input\n");
     if (!mcat_flg) {
-	    fprintf(stderr, "%s not written\n", ofname);
-	    unlink(ofname);
+        fprintf(stderr, "%s not written\n", ofname);
+        unlink(ofname);
     }
-	closerandom();
+    closerandom();
     exit(1);
 }
