@@ -46,7 +46,7 @@ void write_number(FILE *f ,MP_INT *x)
 {
     unsigned char buf[MAXC];
     int i,j;
-    unsigned char length;
+    unsigned int length;
 
     /* encode into buf */
     mptcs(buf,MAXC,x);
@@ -61,7 +61,8 @@ void write_number(FILE *f ,MP_INT *x)
     }
     length = MAXC - i;
 
-    fputc(length, f);
+    fputc((unsigned char)(length & 0xff), f);
+    fputc((unsigned char)(length >> 8), f);
     for (j=i;j<MAXC;j++)
         fputc(buf[j],f);
 }
@@ -69,9 +70,11 @@ void write_number(FILE *f ,MP_INT *x)
 int read_number(FILE *f ,MP_INT *x)
 {
     unsigned char buf[MAXC];
-    int length,i,j;
+    int i,j;
+	unsigned int length;
     
     length = fgetc(f);
+    length |= (fgetc(f) << 8);
     if (length < 0 || length > MAXC)
         return 0;
     for (i=0;i<length;i++) {
@@ -348,7 +351,7 @@ void write_numberx(FILE *f ,MP_INT *x, unsigned char *key, unsigned char *iv)
 {
     unsigned char buf[MAXC];
     int i,j,k;
-    unsigned char length;
+    unsigned int length;
 
     /* encode into buf */
     mptcs(buf,MAXC,x);
@@ -367,7 +370,8 @@ void write_numberx(FILE *f ,MP_INT *x, unsigned char *key, unsigned char *iv)
     i -= (8 - k);
     length += (8 - k);
 
-    fputc(length, f);
+    fputc((unsigned char)(length & 0xff), f);
+    fputc((unsigned char)(length >> 8), f);
     desbuf(EN0,&buf[i],length,key,iv);
     for (j=i;j<MAXC;j++)
         fputc(buf[j],f);
@@ -376,9 +380,11 @@ void write_numberx(FILE *f ,MP_INT *x, unsigned char *key, unsigned char *iv)
 int read_numberx(FILE *f ,MP_INT *x, unsigned char *key, unsigned char *iv)
 {
     unsigned char buf[MAXC];
-    int length,i,j;
+    int i,j;
+	unsigned int length;
     
     length = fgetc(f);
+    length |= (fgetc(f) << 8);
     if (length < 0 || length > MAXC || length % 8)
         return 0;
     for (i=0;i<length;i++) {
@@ -404,7 +410,7 @@ FILE *mfopen(unsigned char *file, unsigned char *mode) {
     FILE *ret;
 
     /* if filename contains a /, just try and open it, otherwise
-     * work along LPATH trying to open file
+     * work along L3PATH trying to open file
      */
 
     if (strchr(file,'/')) {
@@ -413,7 +419,7 @@ FILE *mfopen(unsigned char *file, unsigned char *mode) {
     else {
         po = p = (unsigned char *)malloc(1024);
         npath = 0; ret = NULL;
-        if (pc=(unsigned char *)getenv("LPATH")) {
+        if (pc=(unsigned char *)getenv("L3PATH")) {
             strncpy(p,pc,1024); p[1023] = '\0';
             for (s=p; *p  && (npath < 256); p++) {
                 if (*p == ':') {
