@@ -3,8 +3,8 @@
 #include "l3.h"
 main(int argc,char *argv[])
 {
-    MP_INT *e,*p,*q,*c,*n;
-	char *ps,*qs,*es;
+    MP_INT *e,*p,*q,*c,*n,*d;
+    char *ps,*qs,*es,*ds;
     char prvfile[127]; int i;
     unsigned int idlen;
     unsigned char k[16]; unsigned char iv[8];
@@ -13,7 +13,7 @@ main(int argc,char *argv[])
     int alg=getalg();
     unsigned char *ss;
     FILE *private;
-    init(e); init(p); init(q); init(c); init(n);
+    init(e); init(p); init(q); init(c); init(n); init(d); 
     if (argc < 2) {
         fprintf(stderr, "usage: prvdump prvfile\n");
         exit(1);
@@ -43,11 +43,15 @@ main(int argc,char *argv[])
 
     read_number(private,e);
     mpz_mul(n,p,q);
-	ps = mpz_get_str(NULL, 16, p);
-	printf("p=%s\n",ps);
-	qs = mpz_get_str(NULL, 16, q);
-	printf("q=%s\n",qs);
-	es = mpz_get_str(NULL, 16, e);
-	printf("e=%s\n",es);
+    ps = mpz_get_str(NULL, 16, p);
+    printf("p=%s\n",ps);
+    qs = mpz_get_str(NULL, 16, q);
+    printf("q=%s\n",qs);
+    es = mpz_get_str(NULL, 16, e);
+    printf("e=%s\n",es);
+	mpz_sub_ui(p,p,1); mpz_sub_ui(q,q,1); mpz_mul(p,p,q);
+	modinv(d,e,p);  /* calculate d for RSA for fun */
+    ds = mpz_get_str(NULL, 16, d);
+    printf("RSA\nd=%s\n",ds);
     zap(k,16); zap(hash,16);  zap(ss,strlen(ss));
 }
